diff --git a/components/modules/ai/who_plumerai_people_detection.cpp b/components/modules/ai/who_plumerai_people_detection.cpp
index d7cef77..05c89ae 100644
--- a/components/modules/ai/who_plumerai_people_detection.cpp
+++ b/components/modules/ai/who_plumerai_people_detection.cpp
@@ -33,6 +33,19 @@ constexpr int lcd_height = 240;
 constexpr int lcd_display_height = 180;  // For 4:3 aspect ratio
 camera_fb_t * lcd_buffer = nullptr;
 
+camera_fb_t *frame = NULL;
+
+void resize_for_display_and_free_framebuffer(void *_) {
+    dl::image::resize_image_nearest(
+        reinterpret_cast<uint16_t *>(frame->buf), {(int)frame->height, (int)frame->width, 1},
+        reinterpret_cast<uint16_t *>(lcd_buffer->buf), {lcd_display_height, lcd_width, 1}
+    );
+
+    // The input resizing is done (in network) and so is the LCD resizing (above),
+    // now we can return the framebuffer such that the camera can get a new frame.
+    esp_camera_fb_return(frame);
+}
+
 static const char *TAG = "plumerai_people_detection";
 
 static QueueHandle_t xQueueFrameI = NULL;
@@ -54,8 +67,6 @@ static void task_process_handler(void *arg)
     lcd_buffer->buf = reinterpret_cast<uint8_t *>(heap_caps_aligned_alloc(16, lcd_buffer->len, MALLOC_CAP_8BIT | MALLOC_CAP_SPIRAM));
     for (int i = 0; i < lcd_buffer->len; ++i) { lcd_buffer->buf[i] = 0; }
 
-    camera_fb_t *frame = NULL;
-
     ESP_LOGI(TAG, "Reserving %d bytes of tensor arena in internal RAM", TENSOR_ARENA_SIZE);
     auto tensor_arena = reinterpret_cast<unsigned char *>(heap_caps_aligned_alloc(16, TENSOR_ARENA_SIZE, MALLOC_CAP_8BIT | MALLOC_CAP_INTERNAL));
     if (tensor_arena == nullptr) { ESP_LOGI(TAG, "Error: could not allocate tensor arena"); }
@@ -64,6 +75,8 @@ static void task_process_handler(void *arg)
     auto error_code = PeopleDetectionInit(tensor_arena);
     if (error_code != 0) { ESP_LOGI(TAG, "Error: could not initialize Plumerai People Detection"); }
 
+    PeopleDetectionReadDataCallback(resize_for_display_and_free_framebuffer);
+
     constexpr int max_detections = 20;
     BoxPrediction predictions[max_detections];
 
@@ -74,19 +87,12 @@ static void task_process_handler(void *arg)
             bool is_detected = false;
             if (xQueueReceive(xQueueFrameI, &frame, portMAX_DELAY))
             {
-                dl::image::resize_image_nearest(
-                    reinterpret_cast<uint16_t *>(frame->buf), {(int)frame->height, (int)frame->width, 1},
-                    reinterpret_cast<uint16_t *>(lcd_buffer->buf), {lcd_display_height, lcd_width, 1}
-                );
-
                 int num_results = 0;
                 constexpr float framerate = 2.5f;  // in frames-per-second (FPS)
                 error_code = PeopleDetectionProcessFrame(predictions, max_detections, &num_results, 1 / framerate, frame->buf);
                 if (error_code != 0) { ESP_LOGI(TAG, "Error: could not process a frame using Plumerai People Detection"); }
                 ESP_LOGI(TAG, "Detected %d person(s)", num_results);
 
-                esp_camera_fb_return(frame);
-
                 for (int result_id = 0; result_id < num_results; ++result_id) {
                     draw_detection(predictions[result_id], reinterpret_cast<uint16_t *>(lcd_buffer->buf), lcd_width, lcd_display_height);
                     is_detected = true;
diff --git a/examples/human_face_detection/lcd/main/app_main.cpp b/examples/human_face_detection/lcd/main/app_main.cpp
index cfbeb89..c1b3dd6 100755
--- a/examples/human_face_detection/lcd/main/app_main.cpp
+++ b/examples/human_face_detection/lcd/main/app_main.cpp
@@ -10,7 +10,7 @@ extern "C" void app_main()
     xQueueAIFrame = xQueueCreate(2, sizeof(camera_fb_t *));
     xQueueLCDFrame = xQueueCreate(2, sizeof(camera_fb_t *));
 
-    register_camera(PIXFORMAT_RGB565, FRAMESIZE_VGA, 1, xQueueAIFrame);
+    register_camera(PIXFORMAT_RGB565, FRAMESIZE_VGA, 2, xQueueAIFrame);
     register_plumerai_people_detection(xQueueAIFrame, NULL, NULL, xQueueLCDFrame, false);
     register_lcd(xQueueLCDFrame, NULL, true);
 }
